@@ -91,6 +91,9 @@ class Ontology:
         self.owl_iri = str(self.owl_onto.getOntologyID().getOntologyIRI().get())
         self.owl_classes = self.get_owl_objects("Classes")
         self.owl_object_properties = self.get_owl_objects("ObjectProperties")
+        # for some reason the top object property is included
+        if OWL_TOP_OBJECT_PROPERTY in self.owl_object_properties.keys():
+            del self.owl_object_properties[OWL_TOP_OBJECT_PROPERTY]
         self.owl_data_properties = self.get_owl_objects("DataProperties")
         self.owl_data_factory = self.owl_manager.getOWLDataFactory()
         self.owl_annotation_properties = self.get_owl_objects("AnnotationProperties")
@@ -381,7 +384,7 @@ class Ontology:
             (OWLObject): The changed `OWLObject` entity.
         """
         iri_dict = {IRI.create(entity_iri): IRI.create(replacement_iri)}
-        replacer = OWLObjectDuplicator(self.owlDataFactory, iri_dict)
+        replacer = OWLObjectDuplicator(self.owl_data_factory, iri_dict)
         return replacer.duplicateObject(owl_object)
 
     @paper(
@@ -531,7 +534,7 @@ class OntologyReasoner:
         return self.owl_reasoner.isEntailed(sub_axiom)
 
     def check_disjoint(self, entity1: OWLObject, entity2: OWLObject):
-        """Check if two OWL class expressions are disjoint according to the reasoner."""
+        """Check if two entities are disjoint according to the reasoner."""
         entity_type = self.get_entity_type(entity1)
         assert entity_type == self.get_entity_type(entity2)
 
@@ -622,7 +625,7 @@ class OntologyReasoner:
         !!! credit "Paper"
 
             The definition of **Assumed Disjointness** comes from the paper:
-            *[still-under-review](link)*.
+            [Language Model Analysis for Ontology Subsumption Inference](https://arxiv.org/abs/2302.06761).
 
         !!! note "Assumed Disjointness (Definition)"
             Two class expressions $C$ and $D$ are assumed to be disjoint if they meet the followings:
@@ -682,13 +685,13 @@ class OntologyReasoner:
         print(f"[PASSED {not has_common_descendants}] assumed disjointness check done.")
         return not has_common_descendants
 
-    def check_assumed_disjoint_alternative(self, owl_class1: OWLClassExpression, owl_class2: OWLClassExpression):
+    def check_assumed_disjoint_alternative(self, owl_class1: OWLClassExpression, owl_class2: OWLClassExpression, verbose: bool = False):
         r"""Check if two OWL class expressions satisfy the Assumed Disjointness.
 
         !!! credit "Paper"
 
             The definition of **Assumed Disjointness** comes from the paper:
-            *[still-under-review](link)*.
+            [Language Model Analysis for Ontology Subsumption Inference](https://arxiv.org/abs/2302.06761).
 
         The practical alternative version of [`check_assumed_disjoint`][deeponto.onto.OntologyReasoner.check_assumed_disjoint]
         with following conditions:
@@ -701,7 +704,7 @@ class OntologyReasoner:
             2. **do not** have a **common descendant** (in TBox),
             3. **do not** have a **common instance** (in ABox).
 
-        If either of the conditions have been met, then we assume `class1` and `class2` as disjoint.
+        If all the conditions have been met, then we assume `class1` and `class2` as disjoint.
 
         Examples:
             Suppose pre-load an ontology `onto` from the disease ontology file `doid.owl`.
@@ -709,7 +712,7 @@ class OntologyReasoner:
             ```python
             >>> c1 = onto.get_owl_object_from_iri("http://purl.obolibrary.org/obo/DOID_4058")
             >>> c2 = onto.get_owl_object_from_iri("http://purl.obolibrary.org/obo/DOID_0001816")
-            >>> onto.reasoner.check_assumed_disjoint(c1, c2)
+            >>> onto.reasoner.check_assumed_disjoint(c1, c2, verbose=True)
             [CHECK1 True] input classes have NO subsumption relationship;
             [CHECK2 False] input classes have NO common descendant;
             Failed the `common descendant check`, skip the `common instance` check.
@@ -731,21 +734,26 @@ class OntologyReasoner:
 
         has_subsumption = self.check_subsumption(owl_class1, owl_class2)
         has_subsumption = has_subsumption or self.check_subsumption(owl_class2, owl_class1)
-        print(f"[CHECK1 {not has_subsumption}] input classes have NO subsumption relationship;")
+        if verbose:
+            print(f"[CHECK1 {not has_subsumption}] input classes have NO subsumption relationship;")
         if has_subsumption:
-            print("Failed the `subsumption check`, skip the `common descendant` check.")
-            print(f"[PASSED {not has_subsumption}] assumed disjointness check done.")
+            if verbose:
+                print("Failed the `subsumption check`, skip the `common descendant` check.")
+                print(f"[PASSED {not has_subsumption}] assumed disjointness check done.")
             return False
 
         has_common_descendants = self.check_common_descendants(owl_class1, owl_class2)
-        print(f"[CHECK2 {not has_common_descendants}] input classes have NO common descendant;")
+        if verbose:
+            print(f"[CHECK2 {not has_common_descendants}] input classes have NO common descendant;")
         if has_common_descendants:
-            print("Failed the `common descendant check`, skip the `common instance` check.")
-            print(f"[PASSED {not has_common_descendants}] assumed disjointness check done.")
+            if verbose:
+                print("Failed the `common descendant check`, skip the `common instance` check.")
+                print(f"[PASSED {not has_common_descendants}] assumed disjointness check done.")
             return False
 
         # TODO: `check_common_instances` is still experimental because we have not tested it with ontologies of rich ABox.
         has_common_instances = self.check_common_instances(owl_class1, owl_class2)
-        print(f"[CHECK3 {not has_common_instances}] input classes have NO common instance;")
-        print(f"[PASSED {not has_common_instances}] assumed disjointness check done.")
+        if verbose:
+            print(f"[CHECK3 {not has_common_instances}] input classes have NO common instance;")
+            print(f"[PASSED {not has_common_instances}] assumed disjointness check done.")
         return not has_common_instances
