@@ -62,15 +62,16 @@ class OntologyVerbaliser:
             the names are retrieved from $\texttt{rdfs:label}$.
     """
 
-    def __init__(self, onto: Ontology):
+    def __init__(self, onto: Ontology, apply_lowercasing_to_vocab: bool = False):
         self.onto = onto
         self.parser = OntologySyntaxParser()
         self.nlp = spacy.load("en_core_web_sm")
 
         # build the default vocabulary for entities
+        self.apply_lowercasing_to_vocab = apply_lowercasing_to_vocab
         self.vocab = dict()
         for entity_type in ["Classes", "ObjectProperties", "DataProperties"]:
-            entity_annotations, _ = self.onto.build_annotation_index(entity_type=entity_type, apply_lowercasing=False)
+            entity_annotations, _ = self.onto.build_annotation_index(entity_type=entity_type, apply_lowercasing=self.apply_lowercasing_to_vocab)
             self.vocab.update(**entity_annotations)
         literal_or_iri = lambda k, v: list(v)[0] if v else k  # set vocab to IRI if no string available
         self.vocab = {k: literal_or_iri(k, v) for k, v in self.vocab.items()}  # only set one name for each entity
@@ -83,7 +84,7 @@ class OntologyVerbaliser:
         """
         self.vocab[entity_iri] = entity_name
 
-    def verbalise_class_expression(self, class_expression: Union[OWLClassExpression, RangeNode]):
+    def verbalise_class_expression(self, class_expression: Union[OWLClassExpression, str, RangeNode]):
         r"""Verbalise a class expression (`OWLClassExpression`) or its parsed form (in `RangeNode`).
         
         Currently supported types of class expressions are:
@@ -105,7 +106,7 @@ class OntologyVerbaliser:
         anonymous class **"something"** is appended to the head.
 
         Args:
-            class_expression (Union[OWLClassExpression, RangeNode]): A class expression to be verbalised.
+            class_expression (Union[OWLClassExpression, str, RangeNode]): A class expression to be verbalised.
 
         Raises:
             RuntimeError: Occurs when the class expression is not in one of the supported types.
@@ -252,13 +253,32 @@ class OntologyVerbaliser:
 
         return results
 
-    def verbalise_equivalence_axiom(self, equivalence_axiom: OWLAxiom):
-        #TODO
-        pass
+    # def verbalise_equivalence_axiom(self, equivalence_axiom: OWLAxiom):
+    #     #TODO
+    #     pass
 
-    def verbalise_subsumption_axiom(self, subclassof_axiom: OWLAxiom):
-        #TODO
-        pass
+    def verbalise_subsumption_axiom(self, subsumption_axiom: OWLAxiom):
+        r"""Verbalise a subsumption axiom.
+
+        The subsumption axiom can have two forms:
+        
+        - $C \sqsubseteq D$, the `SubClassOf` axiom;
+        - $C \sqsuperseteq D$, the `SuperClassOf` axiom.
+
+        Args:
+            subsumption_axiom (OWLAxiom): The subsumption axiom to be verbalised.
+        
+        Returns:
+            (Tuple[CfgNode, CfgNode]): The verbalised sub-concept and super-concept (order matters). 
+        """
+        parsed_subsumption_axiom = self.parser.parse(subsumption_axiom).children[0]  # skip the root node
+        if str(subsumption_axiom).startswith("SubClassOf"):
+            parsed_sub_class, parsed_super_class = parsed_subsumption_axiom.children
+        elif str(subsumption_axiom).startswith("SuperClassOf"):
+            parsed_super_class, parsed_sub_class = parsed_subsumption_axiom.children
+        else:
+            raise RuntimeError(f"The input axiom is not a valid subsumption axiom.")
+        return self.verbalise_class_expression(parsed_sub_class), self.verbalise_class_expression(parsed_super_class)
 
 
 class OntologySyntaxParser:
